==> gnumed-client_1.7.5+dfsg.orig.tar.xz: gnumed-client.1.7.5/client/timelinelib/calendar/num/time.py <==
# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
#
# This file is part of Timeline.
#
# Timeline is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Timeline is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Timeline.  If not, see <http://www.gnu.org/licenses/>.


from timelinelib.calendar.time import ComparableValue
from timelinelib.calendar.time import GenericDeltaMixin
from timelinelib.calendar.time import GenericTimeMixin


class NumTime(ComparableValue, GenericTimeMixin):

    @property
    def DeltaClass(self):
        return NumDelta

    def __repr__(self):
        return "{0}<{1!r}>".format(self.__class__.__name__, self.value)

    def __add__(self, other):
        if isinstance(other, self.DeltaClass):
            # Time + Delta
            return self.__class__(self.value + other.value)
        else:
            return NotImplemented

    def __sub__(self, other):
        if isinstance(other, self.DeltaClass):
            # Time - Delta
            return self.__class__(self.value - other.value)
        elif isinstance(other, self.__class__):
            # Time - Time
            return self.DeltaClass(self.value - other.value)
        else:
            return NotImplemented


class NumDelta(ComparableValue, GenericDeltaMixin):

    def __repr__(self):
        return "{0}<{1!r}>".format(self.__class__.__name__, self.value)

    def __sub__(self, other):
        if isinstance(other, self.__class__):
            # Delta - Delta
            return self.__class__(self.value - other.value)
        else:
            return NotImplemented

    def __mul__(self, other):
        # Delta * number
        return self.__class__(self.value * other)

    def __div__(self, other):
        if isinstance(other, self.__class__):
            # Delta / Delta
            return float(self.value) / float(other.value)
        else:
            # Delta / number
            return self.__class__(self.value / other)

==> gnumed-client_1.8.7+dfsg.orig.tar.xz: gnumed-client.1.8.7/client/timelinelib/calendar/num/time.py <==
# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018  Rickard Lindberg, Roger Lindberg
#
# This file is part of Timeline.
#
# Timeline is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Timeline is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Timeline.  If not, see <http://www.gnu.org/licenses/>.


from timelinelib.calendar.time import ComparableValue
from timelinelib.calendar.time import GenericDeltaMixin
from timelinelib.calendar.time import GenericTimeMixin


class NumTime(ComparableValue, GenericTimeMixin):

    @property
    def DeltaClass(self):
        return NumDelta

    def __repr__(self):
        return "{0}<{1!r}>".format(self.__class__.__name__, self.value)

    def __add__(self, other):
        if isinstance(other, self.DeltaClass):
            # Time + Delta
            return self.__class__(self.value + other.value)
        else:
            return NotImplemented

    def __sub__(self, other):
        if isinstance(other, self.DeltaClass):
            # Time - Delta
            return self.__class__(self.value - other.value)
        elif isinstance(other, self.__class__):
            # Time - Time
            return self.DeltaClass(self.value - other.value)
        else:
            return NotImplemented


class NumDelta(ComparableValue, GenericDeltaMixin):

    def __repr__(self):
        return "{0}<{1!r}>".format(self.__class__.__name__, self.value)

    def __sub__(self, other):
        if isinstance(other, self.__class__):
            # Delta - Delta
            return self.__class__(self.value - other.value)
        else:
            return NotImplemented

    def __mul__(self, other):
        # Delta * number
        return self.__class__(int(self.value * other))

    def __truediv__(self, other):
        if isinstance(other, self.__class__):
            # Delta / Delta
            return self.value / other.value
        else:
            # Delta / number
            return self.__class__(int(self.value // other))
